@@ -17,7 +17,7 @@ COLUMN_NAME_MAPPER = {
 }
 
 COLUMNS_BY_MODALITY = {
-    AUDIO: ["tier", "object", "utterance_type", "object_present",
+    AUDIO: ["ordinal", "tier", "object", "utterance_type", "object_present",
             "speaker", "timestamp", "basic_level", "annotid", 'pho'],
     VIDEO: ["ordinal", "onset", "offset",
             "object", "utterance_type", "object_present",
@@ -128,10 +128,9 @@ def gather_all_basic_level_annotations(keep_comments=False, keep_basic_level_na=
     if not keep_basic_level_na:
         all_df = all_df[~all_df.basic_level.isna()]
 
-    # Sort by modality, month and subject for consistency with the older R code.
-    # And then by ordinal (relevent for opfs only), onset, offset, and annotid for semi-consistency between versions
-    all_df = all_df.sort_values(by=['audio_video', 'month', 'subj', 'ordinal', 'onset', 'offset', 'annotid'],
-                                ascending=[False, True, True, True, True, True, True])
+    # Sort by modality, month and subject, and ordinal for consistency between versions.
+    all_df = all_df.sort_values(by=['audio_video', 'month', 'subj', 'ordinal'],
+                                ascending=[False, True, True, True])
 
     # Convert a subset of the columns to factors (categorical in the pandas's terms)
     factor_columns = ['object', 'utterance_type',
